#[non_exhaustive]
pub enum Error {
    NotEnoughSpace,
    NotAscii,
    NotOnCharBoundary,
}
Available on crate feature fmt only.
An error while trying to write into a StrWriter.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

NotEnoughSpace

Attempted to write something into the buffer when there isn’t enough space to write it.

NotAscii

For compatibility with NotAsciiError

NotOnCharBoundary

Attempted to index a string arguent by an range where one of the bounds was not on a char boundary.

Implementations

For panicking at compile-time, with a compile-time error that says what the error is.