Module const_format::for_examples [−][src]
This is supported on crate feature
fmt only.Types for the documentation examples.
Features
This module is only exported with the “fmt” feature, and the nightly compiler,
because at the time of writing these docs (2020-08-XX) mutable references in const fn
require the unstable
const_mut_refs feature.
Structs
| Point3 | An example struct which implements const debug formatting. |
| Unit | An example unit struct which implements const debug formatting. |